@@ -5,7 +5,7 @@
 import abc
 from collections import OrderedDict
 
-from .._common import get_file_encoding
+from .._common import get_file_encoding, json
 from .._constant import SourceType
 from .._constant import TableNameTemplate as tnt
 from .._logger import FileSourceLogger, TextSourceLogger
@@ -15,12 +15,6 @@ from ..interface import AbstractTableReader
 from .formatter import JsonTableFormatter
 
 
-try:
-    import simplejson as json
-except ImportError:
-    import json  # type: ignore
-
-
 class JsonTableLoader(AbstractTableReader, metaclass=abc.ABCMeta):
     """
     An abstract class of JSON table loaders.
@@ -433,14 +427,14 @@ class JsonTableFileLoader(JsonTableLoader):
         self._logger.logging_load()
         self.encoding = get_file_encoding(self.source, self.encoding)
 
-        with open(self.source, "r", encoding=self.encoding) as fp:
+        with open(self.source, encoding=self.encoding) as fp:
             try:
                 return json.load(fp, object_pairs_hook=OrderedDict)
             except ValueError as e:
                 raise ValidationError(e)
 
     def _get_default_table_name_template(self):
-        return "{:s}_{:s}".format(tnt.FILENAME, tnt.KEY)
+        return f"{tnt.FILENAME:s}_{tnt.KEY:s}"
 
 
 class JsonTableTextLoader(JsonTableLoader):
@@ -505,7 +499,7 @@ class JsonTableTextLoader(JsonTableLoader):
         return json.loads(self.source, object_pairs_hook=OrderedDict)
 
     def _get_default_table_name_template(self):
-        return "{:s}".format(tnt.KEY)
+        return f"{tnt.KEY:s}"
 
 
 class JsonTableDictLoader(JsonTableLoader):
@@ -553,4 +547,4 @@ class JsonTableDictLoader(JsonTableLoader):
         return self.source
 
     def _get_default_table_name_template(self):
-        return "{:s}".format(tnt.KEY)
+        return f"{tnt.KEY:s}"
