@@ -21,8 +21,8 @@ def fifo_writer(fifo_name, text):
 
 
 def print_test_result(expected, actual, error=None):
-    print("[expected]\n{}\n".format(expected))
-    print("[actual]\n{}\n".format(actual))
+    print(f"[expected]\n{expected}\n")
+    print(f"[actual]\n{actual}\n")
 
     if error:
         print(error, file=sys.stderr)
